package schedframe.scheduling.tasks.phases;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.qcg.broker.schemas.resreqs.ComputingResourceBaseTypeItem;
import org.qcg.broker.schemas.resreqs.ComputingResourceParameterType;
import org.qcg.broker.schemas.resreqs.PhaseBehaviourType;
import org.qcg.broker.schemas.resreqs.StringParameterType;

import org.qcg.broker.schemas.resreqs.ResourceConsumptionType;

public class ResourceConsumption {

	protected String id;
    protected Map<String, String> referenceHardware;
    protected long duration;
    protected List<PhaseBehaviour> phaseBehaviourList;
    
    public ResourceConsumption(long duration, ComputingResourceBaseTypeItem item[]){
    	this.id = null;
    	this.referenceHardware = null;
    	this.duration = duration;
    	this.phaseBehaviourList = new ArrayList<PhaseBehaviour>();
    	for(ComputingResourceBaseTypeItem compResItem: item){
    		ComputingResourceParameterType hostParameter = compResItem.getHostParameter();
        	PhaseBehaviour pb = new PhaseBehaviour(hostParameter.getName().toString());
        	phaseBehaviourList.add(pb);
    	}
    }
    
    public ResourceConsumption(ResourceConsumptionType resConsumptionType){
    	this.id = resConsumptionType.getId();
    	this.referenceHardware = new HashMap<String, String>();
    	if(resConsumptionType.getReferenceHardware() != null){
        	for (int i = 0; i < resConsumptionType.getReferenceHardware().getReference().length; i++){
        		StringParameterType spt = resConsumptionType.getReferenceHardware().getReference(i);
        		referenceHardware.put(spt.getName(), spt.getContent());
        	}
    	}
    	this.duration = resConsumptionType.getDuration().toLong()/1000;
    	this.phaseBehaviourList = new ArrayList<PhaseBehaviour>();
    	for(PhaseBehaviourType pbt: resConsumptionType.getBehaviour()){
        	PhaseBehaviour pb = new PhaseBehaviour(pbt);
        	phaseBehaviourList.add(pb);
    	}
    }
    
	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public Map<String, String> getReferenceHardware() {
		return referenceHardware;
	}

	public long getDuration() {
		return duration;
	}

	public List<PhaseBehaviour> getBehaviourList() {
		return phaseBehaviourList;
	}

}
